from setuptools import setup, find_packages

setup(
    name = 'django-apps',
    version = __import__('django_apps').__version__,
    description = 'Django application which provides an information about installed applications.',
    keywords = 'django apps',
    license = 'New BSD License',
    author = 'Alexander Artemenko',
    author_email = 'svetlyak.40wt@gmail.com',
    url = 'http://github.com/svetlyak40wt/django-apps/',
    install_requires = [],
    dependency_links = ['http://pypi.aartemenko.com'],
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Environment :: Plugins',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    packages = find_packages(),
    include_package_data = True,
)




import re
from django.utils.translation import ugettext_lazy as _

_apps_descriptions = [
    (r'.*django_dzenlog',               _('Abstract blogging application.')),
    (r'.*django_markdown2',             _('Markdown2 filter tag.')),
    (r'.*dzenlog_text',                 _('Text posts for blog (based on django_dzenlog).')),
    (r'.*dzenlog_link',                 _('Link posts for blog (based on django_dzenlog).')),
    (r'.*tagging',                      _('General tagging apllication.')),
    (r'.*django_faces',                 _('Pavatar, gravatar and favicons based avatars.')),
    (r'.*django_apps',                  _('Shows the installed application, their versions and descriptions.')),
    (r'.*pagination',                   _('Limits number of entries per page.')),
    (r'.*threadedcomments',             _('Flexible threaded commenting system.')),
    (r'.*dbtemplates',                  _('Editable templates, stored in the database.')),
    (r'.*django_openid',                _('OpenID server and consumer.')),
    (r'.*django_freetext',              _('Editable pieces of the content.')),
    (r'.*compress',                     _('Javascript and CSS compressor.')),
    (r'.*utils',                        _('Misc stuff.')),
    (r'.*django_extensions',            _('Global custom management extensions.')),
    (r'.*basic.inlines',                _('Inline markup to insert content objects into other pieces of content.')),
    (r'.*basic.media',                  _('Audio, video and images.')),
    (r'.*django.contrib.auth',          _('Django\'s authentication framework.')),
    (r'.*django.contrib.contenttypes',  _('Framework for hooking into "types" of content.')),
    (r'.*django.contrib.sessions',      _('Sessions support.')),
    (r'.*django.contrib.sites',         _('Multi-site support.')),
    (r'.*django.contrib.admin',         _('The automatic Django administrative interface.')),
    (r'.*django.contrib.humanize',      _('Template filters for adding a "human touch" to data.')),
    (r'.*django.contrib.flatpages',     _('Framework for managing simple "flat" HTML content in a database.')),
    (r'.*django.contrib.sitemaps',      _('A framework for generating Google sitemap XML files.')),
    (r'.*django.contrib.webdesign',     _('Helpers and utilities for Web designers.')),
]

def get_description(app_name):
    for pattern, description in _apps_descriptions:
        if re.match(pattern, app_name) is not None:
            return description
    return ''




import re
from django import template
from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from django_apps.descriptions import get_description

register = template.Library()

class InstalledAppsNode(template.Node):
    def __init__(self, var_name):
        self.var_name = var_name

    def render(self, context):
        def get_info(module_name):
            mod = __import__(module_name)
            version = getattr(mod, '__version__',
                      getattr(mod, 'VERSION', _('unknown')))
            if isinstance(version, (tuple, list)):
                version = '.'.join(map(str, version))
            return dict(name = module_name,
                        version = version,
                        description = get_description(module_name))

        try:
            context[self.var_name] = [get_info(mod) for mod in settings.INSTALLED_APPS]
        except Exception, e:
            context[self.var_name] = e
        print context[self.var_name]
        return ''

def installed_apps(parser, token):
    try:
        tag_name, arg = token.contents.split(None, 1)
    except ValueError:
        raise template.TemplateSyntaxError, "%r tag requires arguments" % token.contents.split()[0]
    m = re.search(r'as (\w+)', arg)
    if not m:
        raise template.TemplateSyntaxError, "%r tag had invalid arguments" % tag_name
    var_name = m.groups()[0]
    return InstalledAppsNode(var_name)

register.tag(installed_apps)

